<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>CardWidget</name>
    <message>
        <location filename="../cardwidget.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../cardwidget.ui" line="29"/>
        <source>Card Name</source>
        <translation>Назва карти</translation>
    </message>
    <message>
        <location filename="../cardwidget.ui" line="47"/>
        <source>Profile:</source>
        <translation>Профіль:</translation>
    </message>
    <message>
        <location filename="../cardwidget.cc" line="67"/>
        <source>pa_context_set_card_profile_by_index() failed</source>
        <translation>Спроба виконання pa_context_set_card_profile_by_index() була невдалою</translation>
    </message>
</context>
<context>
    <name>Channel</name>
    <message>
        <location filename="../channel.cc" line="89"/>
        <source>%1% (%2dB)</source>
        <comment>volume slider label [X% (YdB)]</comment>
        <translation>%1% (%2дБ)</translation>
    </message>
    <message>
        <location filename="../channel.cc" line="93"/>
        <source>%1%</source>
        <comment>volume slider label [X%]</comment>
        <translation>%1%</translation>
    </message>
    <message>
        <location filename="../channel.cc" line="160"/>
        <source>&lt;small&gt;Silence&lt;/small&gt;</source>
        <translation>&lt;small&gt;Тиша&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../channel.cc" line="160"/>
        <source>&lt;small&gt;Min&lt;/small&gt;</source>
        <translation>&lt;small&gt;Мін.&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../channel.cc" line="162"/>
        <source>&lt;small&gt;100% (0dB)&lt;/small&gt;</source>
        <translation>&lt;small&gt;100% (0дБ)&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../channel.cc" line="165"/>
        <source>&lt;small&gt;&lt;i&gt;Base&lt;/i&gt;&lt;/small&gt;</source>
        <translation>&lt;small&gt;&lt;i&gt;Основний&lt;/i&gt;&lt;/small&gt;</translation>
    </message>
</context>
<context>
    <name>ChannelWidget</name>
    <message>
        <location filename="../channelwidget.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../channelwidget.ui" line="20"/>
        <source>&lt;b&gt;left-front&lt;/b&gt;</source>
        <translation>&lt;b&gt;лівий передній&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../channelwidget.ui" line="34"/>
        <source>&lt;small&gt;50%&lt;/small&gt;</source>
        <translation>&lt;small&gt;50%&lt;/small&gt;</translation>
    </message>
</context>
<context>
    <name>DeviceWidget</name>
    <message>
        <location filename="../devicewidget.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="36"/>
        <source>Device Title</source>
        <translation>Назва пристрою</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="56"/>
        <source>Mute audio</source>
        <translation>Заглушити звук</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="69"/>
        <source>Lock channels together</source>
        <translation>Пов&apos;язати канали разом</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="85"/>
        <source>Set as fallback</source>
        <translation>Встановити запасним</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="103"/>
        <source>&lt;b&gt;Port:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Порт:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="126"/>
        <source>Show advanced options</source>
        <translation>Показати розширені параметри</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="172"/>
        <source>PCM</source>
        <translation>PCM</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="182"/>
        <source>AC3</source>
        <translation>AC3</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="189"/>
        <source>EAC3</source>
        <translation>EAC3</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="196"/>
        <source>DTS</source>
        <translation>DTS</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="203"/>
        <source>MPEG</source>
        <translation>MPEG</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="210"/>
        <source>AAC</source>
        <translation>AAC</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="238"/>
        <source>&lt;b&gt;Latency offset:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Затримка зсуву:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="245"/>
        <source> ms</source>
        <translation> мс</translation>
    </message>
    <message>
        <location filename="../devicewidget.cc" line="42"/>
        <source>Rename device...</source>
        <translation>Перейменувати пристрій...</translation>
    </message>
    <message>
        <location filename="../devicewidget.cc" line="156"/>
        <source>pa_context_set_port_latency_offset() failed</source>
        <translation>Спроба виконання pa_context_set_port_latency_offset() була невдалою</translation>
    </message>
    <message>
        <location filename="../devicewidget.cc" line="227"/>
        <source>Sorry, but device renaming is not supported.</source>
        <translation>Вибачте, але перейменування пристрою не підтримується.</translation>
    </message>
    <message>
        <location filename="../devicewidget.cc" line="228"/>
        <source>You need to load module-device-manager in the PulseAudio server in order to rename devices</source>
        <translation>Вам потрібно завантажити module-device-manager на сервері PulseAudio, щоб мати змогу перейменовувати пристрої</translation>
    </message>
    <message>
        <location filename="../devicewidget.cc" line="234"/>
        <source>Rename device %1 to:</source>
        <translation>Перейменувати пристрій %1 на:</translation>
    </message>
    <message>
        <location filename="../devicewidget.cc" line="241"/>
        <source>pa_ext_device_manager_set_device_description() failed</source>
        <translation>Збій pa_ext_device_manager_set_device_description()</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Volume Control</source>
        <translation>Керування гучністю</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="28"/>
        <source>&amp;Playback</source>
        <translation>В&amp;ідтворення</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>&lt;i&gt;No application is currently playing audio.&lt;/i&gt;</source>
        <translation>&lt;i&gt;Жодна з програм не відтворює звукових даних.&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="66"/>
        <location filename="../mainwindow.ui" line="131"/>
        <location filename="../mainwindow.ui" line="196"/>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Show:</source>
        <translation>Показ:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <location filename="../mainwindow.ui" line="139"/>
        <source>All Streams</source>
        <translation>Всі потоки</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <location filename="../mainwindow.ui" line="144"/>
        <source>Applications</source>
        <translation>Програми</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <location filename="../mainwindow.ui" line="149"/>
        <source>Virtual Streams</source>
        <translation>Віртуальні потоки</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>&amp;Recording</source>
        <translation>&amp;Запис</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>&lt;i&gt;No application is currently recording audio.&lt;/i&gt;</source>
        <translation>&lt;i&gt;Жодна з програм не виконує запису звукових даних.&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>&amp;Output Devices</source>
        <translation>Пристрої &amp;відтворення</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>&lt;i&gt;No output devices available&lt;/i&gt;</source>
        <translation>&lt;i&gt;Пристроїв відтворення звукових даних не знайдено&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="204"/>
        <source>All Output Devices</source>
        <translation>Всі пристрої виводу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Hardware Output Devices</source>
        <translation>Фізичні пристрої виводу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>Virtual Output Devices</source>
        <translation>Віртуальні пристрої виводу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="223"/>
        <source>&amp;Input Devices</source>
        <translation>Пристрої &amp;вводу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="250"/>
        <source>&lt;i&gt;No input devices available&lt;/i&gt;</source>
        <translation>&lt;i&gt;Пристроїв вводу не знайдено&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="269"/>
        <source>All Input Devices</source>
        <translation>Всі пристрої вводу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>All Except Monitors</source>
        <translation>Всі крім моніторів</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="279"/>
        <source>Hardware Input Devices</source>
        <translation>Фізичні пристрої вводу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <source>Virtual Input Devices</source>
        <translation>Віртуальні пристрої вводу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Monitors</source>
        <translation>Монітори</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>&amp;Configuration</source>
        <translation>&amp;Налаштування</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>&lt;i&gt;No cards available for configuration&lt;/i&gt;</source>
        <translation>&lt;i&gt;Карток для налаштування не знайдено&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="336"/>
        <source>Show volume meters</source>
        <translation>Показати вимірювання гучності</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="347"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="159"/>
        <source> (plugged in)</source>
        <translation> (під&apos;єднано)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="163"/>
        <location filename="../mainwindow.cc" line="259"/>
        <source> (unavailable)</source>
        <translation> (недоступно)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="165"/>
        <location filename="../mainwindow.cc" line="256"/>
        <source> (unplugged)</source>
        <translation> (від&apos;єднано)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="390"/>
        <source>Failed to read data from stream</source>
        <translation>Спроба читання даних з потоку була невдалою</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="434"/>
        <source>Peak detect</source>
        <translation>Визначення максимумів</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="435"/>
        <source>Failed to create monitoring stream</source>
        <translation>Не вдалося створити потік для спостереження</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="450"/>
        <source>Failed to connect monitoring stream</source>
        <translation>Не вдалося з’єднатися з потоком для спостереження</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="590"/>
        <source>Ignoring sink-input due to it being designated as an event and thus handled by the Event widget</source>
        <translation>Нехтування вхідним сигналом, оскільки його визначено подією та оброблено віджетом події</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="762"/>
        <source>System Sounds</source>
        <translation>Системні звуки</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="1092"/>
        <source>Establishing connection to PulseAudio. Please wait...</source>
        <translation>Встановлено з&apos;єднання з PulseAudio. Зачекайте, будь ласка...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../pavucontrol.cc" line="66"/>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="87"/>
        <source>Card callback failure</source>
        <translation>Спроба зворотного виклику карти зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="110"/>
        <source>Sink callback failure</source>
        <translation>Спроба зворотного виклику приймача зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="133"/>
        <source>Source callback failure</source>
        <translation>Спроба зворотного виклику джерела зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="152"/>
        <source>Sink input callback failure</source>
        <translation>Спроба зворотного виклику потоку отримання приймача зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="171"/>
        <source>Source output callback failure</source>
        <translation>Спроба зворотного виклику потоку відтворення джерела зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="211"/>
        <source>Client callback failure</source>
        <translation>Спроба зворотного виклику клієнта зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="227"/>
        <source>Server info callback failure</source>
        <translation>Спроба зворотного виклику даних сервера зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="245"/>
        <location filename="../pavucontrol.cc" line="542"/>
        <source>Failed to initialize stream_restore extension: %s</source>
        <translation>Не вдалося ініціалізувати розширення stream_restore : %s</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="263"/>
        <source>pa_ext_stream_restore_read() failed</source>
        <translation>Спроба виконати pa_ext_stream_restore_read() зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="281"/>
        <location filename="../pavucontrol.cc" line="556"/>
        <source>Failed to initialize device restore extension: %s</source>
        <translation>Не вдалося ініціалізувати розширення відновлення пристрою : %s</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="302"/>
        <source>pa_ext_device_restore_read_sink_formats() failed</source>
        <translation>Спроба виконати pa_ext_device_restore_read_sink_formats() зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="320"/>
        <location filename="../pavucontrol.cc" line="569"/>
        <source>Failed to initialize device manager extension: %s</source>
        <translation>Не вдалося ініціалізувати розширення керуванням пристрою : %s</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="339"/>
        <source>pa_ext_device_manager_read() failed</source>
        <translation>Спроба виконання pa_ext_device_manager_read() була невдалою</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="356"/>
        <source>pa_context_get_sink_info_by_index() failed</source>
        <translation>Спроба виконати pa_context_get_sink_info_by_index() зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="369"/>
        <source>pa_context_get_source_info_by_index() failed</source>
        <translation>Спроба виконати pa_context_get_source_info_by_index() зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="382"/>
        <location filename="../pavucontrol.cc" line="395"/>
        <source>pa_context_get_sink_input_info() failed</source>
        <translation>Спроба виконати pa_context_get_sink_input_info() зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="408"/>
        <source>pa_context_get_client_info() failed</source>
        <translation>Спроба виконати pa_context_get_client_info() зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="418"/>
        <location filename="../pavucontrol.cc" line="483"/>
        <source>pa_context_get_server_info() failed</source>
        <translation>Спроба виконати pa_context_get_server_info() зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="431"/>
        <source>pa_context_get_card_info_by_index() failed</source>
        <translation>Спроба виконати pa_context_get_card_info_by_index() зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="474"/>
        <source>pa_context_subscribe() failed</source>
        <translation>Спроба виконати pa_context_subscribe() зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="490"/>
        <source>pa_context_client_info_list() failed</source>
        <translation>Спроба виконати pa_context_client_info_list() зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="497"/>
        <source>pa_context_get_card_info_list() failed</source>
        <translation>Спроба виконати pa_context_get_card_info_list() зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="504"/>
        <source>pa_context_get_sink_info_list() failed</source>
        <translation>Спроба виконати pa_context_get_sink_info_list() зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="511"/>
        <source>pa_context_get_source_info_list() failed</source>
        <translation>Спроба виконати pa_context_get_source_info_list() зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="518"/>
        <source>pa_context_get_sink_input_info_list() failed</source>
        <translation>Спроба виконати pa_context_get_sink_input_info_list() зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="525"/>
        <source>pa_context_get_source_output_info_list() failed</source>
        <translation>Спроба виконати pa_context_get_source_output_info_list() зазнала невдачі</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="584"/>
        <location filename="../pavucontrol.cc" line="635"/>
        <source>Connection failed, attempting reconnect</source>
        <translation>Зв&apos;язок втрачено, спроба зв&apos;язатися знову</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="607"/>
        <location filename="../pavucontrol.cc" line="664"/>
        <source>PulseAudio Volume Control</source>
        <translation>Керування гучністю PulseAudio</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="622"/>
        <source>Connection to PulseAudio failed. Automatic retry in 5s.&lt;br&gt;&lt;br&gt;In this case this is likely because PULSE_SERVER in the Environment/X11 Root Window Propertiesor default-server in client.conf is misconfigured.&lt;br&gt;This situation can also arrise when PulseAudio crashed and left stale details in the X11 Root Window.&lt;br&gt;If this is the case, then PulseAudio should autospawn again, or if this is not configured you shouldrun start-pulseaudio-x11 manually.</source>
        <translation>Не вдалося з&apos;єднатися з PulseAudio. Автоматична повторна спроба за 5 секунд.&lt;br&gt;&lt;br&gt;У цьому випадку це може статися через неправильне налаштування параметра PULSE_SERVER в Environment/X11 Root Window Properties або default-server у client.conf.&lt;br&gt;Така ситуація також може виникнути, якщо стався збій PulseAudio і залишились застарілі дані у X11 Root Window..&lt;br&gt;Якщо це так, то PulseAudio має знову автозапуститися, або, якщо це не налаштовано, вам слід запустити start-pulseaudio-x11 вручну.</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="672"/>
        <source>Select a specific tab on load.</source>
        <translation>Вибрати специфічну вкладку при завантаженні.</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="675"/>
        <source>Retry forever if pa quits (every 5 seconds).</source>
        <translation>Пробувати знову, якщо PulseAudio завершиться (кожні 5 секунд).</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="678"/>
        <source>Maximize the window.</source>
        <translation>Максималізувати вікно.</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="703"/>
        <source>Fatal Error: Unable to connect to PulseAudio</source>
        <translation>Фатальна помилка: Неможливо зв&apos;язатися з PulseAudio</translation>
    </message>
</context>
<context>
    <name>RoleWidget</name>
    <message>
        <location filename="../rolewidget.cc" line="59"/>
        <source>pa_ext_stream_restore_write() failed</source>
        <translation>Спроба виконання pa_ext_stream_restore_write() була невдалою</translation>
    </message>
</context>
<context>
    <name>SinkInputWidget</name>
    <message>
        <location filename="../sinkinputwidget.cc" line="36"/>
        <source>on</source>
        <translation>на</translation>
    </message>
    <message>
        <location filename="../sinkinputwidget.cc" line="39"/>
        <source>Terminate Playback</source>
        <translation>Завершити відтворення</translation>
    </message>
    <message>
        <location filename="../sinkinputwidget.cc" line="52"/>
        <source>Unknown output</source>
        <translation>Невідомий пристрій відтворення</translation>
    </message>
    <message>
        <location filename="../sinkinputwidget.cc" line="63"/>
        <source>pa_context_set_sink_input_volume() failed</source>
        <translation>Спроба виконання pa_context_set_sink_input_volume() була невдалою</translation>
    </message>
    <message>
        <location filename="../sinkinputwidget.cc" line="78"/>
        <source>pa_context_set_sink_input_mute() failed</source>
        <translation>Спроба виконання pa_context_set_sink_input_mute() була невдалою</translation>
    </message>
    <message>
        <location filename="../sinkinputwidget.cc" line="88"/>
        <source>pa_context_kill_sink_input() failed</source>
        <translation>Спроба виконання pa_context_kill_sink_input() була невдалою</translation>
    </message>
    <message>
        <location filename="../sinkinputwidget.cc" line="113"/>
        <source>pa_context_move_sink_input_by_index() failed</source>
        <translation>Спроба виконання pa_context_move_sink_input_by_index() була невдалою</translation>
    </message>
</context>
<context>
    <name>SinkWidget</name>
    <message>
        <location filename="../sinkwidget.cc" line="81"/>
        <source>pa_context_set_sink_volume_by_index() failed</source>
        <translation>Спроба виконання pa_context_set_sink_volume_by_index() була невдалою</translation>
    </message>
    <message>
        <location filename="../sinkwidget.cc" line="96"/>
        <source>pa_context_set_sink_mute_by_index() failed</source>
        <translation>Спроба виконання pa_context_set_sink_mute_by_index() була невдалою</translation>
    </message>
    <message>
        <location filename="../sinkwidget.cc" line="110"/>
        <source>pa_context_set_default_sink() failed</source>
        <translation>Спроба виконання pa_context_set_default_sink() була невдалою</translation>
    </message>
    <message>
        <location filename="../sinkwidget.cc" line="126"/>
        <source>pa_context_set_sink_port_by_index() failed</source>
        <translation>Спроба виконання pa_context_set_sink_port_by_index() була невдалою</translation>
    </message>
    <message>
        <location filename="../sinkwidget.cc" line="166"/>
        <source>pa_ext_device_restore_save_sink_formats() failed</source>
        <translation>Спроба виконати pa_ext_device_restore_save_sink_formats() зазнала невдачі</translation>
    </message>
</context>
<context>
    <name>SourceOutputWidget</name>
    <message>
        <location filename="../sourceoutputwidget.cc" line="35"/>
        <source>from</source>
        <translation>з</translation>
    </message>
    <message>
        <location filename="../sourceoutputwidget.cc" line="39"/>
        <source>Terminate Recording</source>
        <translation>Завершити запис</translation>
    </message>
    <message>
        <location filename="../sourceoutputwidget.cc" line="59"/>
        <source>Unknown input</source>
        <translation>Невідоме джерело даних</translation>
    </message>
    <message>
        <location filename="../sourceoutputwidget.cc" line="71"/>
        <source>pa_context_set_source_output_volume() failed</source>
        <translation>Спроба виконання pa_context_set_source_output_volume() була невдалою</translation>
    </message>
    <message>
        <location filename="../sourceoutputwidget.cc" line="86"/>
        <source>pa_context_set_source_output_mute() failed</source>
        <translation>Спроба виконання pa_context_set_source_output_mute() була невдалою</translation>
    </message>
    <message>
        <location filename="../sourceoutputwidget.cc" line="97"/>
        <source>pa_context_kill_source_output() failed</source>
        <translation>Спроба виконання pa_context_kill_source_output() була невдалою</translation>
    </message>
    <message>
        <location filename="../sourceoutputwidget.cc" line="124"/>
        <source>pa_context_move_source_output_by_index() failed</source>
        <translation>Спроба виконання pa_context_move_source_output_by_index() була невдалою</translation>
    </message>
</context>
<context>
    <name>SourceWidget</name>
    <message>
        <location filename="../sourcewidget.cc" line="35"/>
        <source>pa_context_set_source_volume_by_index() failed</source>
        <translation>Спроба виконання pa_context_set_source_volume_by_index() була невдалою</translation>
    </message>
    <message>
        <location filename="../sourcewidget.cc" line="50"/>
        <source>pa_context_set_source_mute_by_index() failed</source>
        <translation>Спроба виконання pa_context_set_source_mute_by_index() була невдалою</translation>
    </message>
    <message>
        <location filename="../sourcewidget.cc" line="64"/>
        <source>pa_context_set_default_source() failed</source>
        <translation>Спроба виконання pa_context_set_default_source() була невдалою</translation>
    </message>
    <message>
        <location filename="../sourcewidget.cc" line="80"/>
        <source>pa_context_set_source_port_by_index() failed</source>
        <translation>Спроба виконання pa_context_set_source_port_by_index() була невдалою</translation>
    </message>
</context>
<context>
    <name>StreamWidget</name>
    <message>
        <location filename="../streamwidget.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../streamwidget.ui" line="32"/>
        <source>Device Title</source>
        <translation>Назва пристрою</translation>
    </message>
    <message>
        <location filename="../streamwidget.ui" line="52"/>
        <source>direction</source>
        <translation>напрямок</translation>
    </message>
    <message>
        <location filename="../streamwidget.ui" line="59"/>
        <source>device</source>
        <translation>пристрій</translation>
    </message>
    <message>
        <location filename="../streamwidget.ui" line="66"/>
        <source>Mute audio</source>
        <translation>Заглушити звук</translation>
    </message>
    <message>
        <location filename="../streamwidget.ui" line="79"/>
        <source>Lock channels together</source>
        <translation>Пов&apos;язати канали разом</translation>
    </message>
    <message>
        <location filename="../streamwidget.cc" line="34"/>
        <source>Terminate</source>
        <translation>Перервати відтворення</translation>
    </message>
</context>
</TS>
